pub struct BuildfixAction {
pub action_type: BuildfixActionType,
pub target: Option<BuildfixActionTarget>,
pub content: Option<String>,
pub command: Option<String>,
pub description: Option<String>,
}Fields
action_type: BuildfixActionTypetarget: Option<BuildfixActionTarget>content: Option<String>command: Option<String>description: Option<String>Trait Implementations
Sourceimpl Clone for BuildfixAction
impl Clone for BuildfixAction
Sourcefn clone(&self) -> BuildfixAction
fn clone(&self) -> BuildfixAction
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BuildfixAction
impl Debug for BuildfixAction
Sourceimpl<'de> Deserialize<'de> for BuildfixAction
impl<'de> Deserialize<'de> for BuildfixAction
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BuildfixAction
impl JsonSchema for BuildfixAction
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for BuildfixAction
impl PartialEq for BuildfixAction
Sourceimpl Serialize for BuildfixAction
impl Serialize for BuildfixAction
impl Eq for BuildfixAction
impl StructuralPartialEq for BuildfixAction