pub struct BuildfixLocation {
pub path: Option<String>,
pub line: Option<u32>,
pub col: Option<u32>,
}Fields
path: Option<String>line: Option<u32>col: Option<u32>Trait Implementations
Sourceimpl Clone for BuildfixLocation
impl Clone for BuildfixLocation
Sourcefn clone(&self) -> BuildfixLocation
fn clone(&self) -> BuildfixLocation
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BuildfixLocation
impl Debug for BuildfixLocation
Sourceimpl<'de> Deserialize<'de> for BuildfixLocation
impl<'de> Deserialize<'de> for BuildfixLocation
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BuildfixLocation
impl JsonSchema for BuildfixLocation
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for BuildfixLocation
impl PartialEq for BuildfixLocation
Sourceimpl Serialize for BuildfixLocation
impl Serialize for BuildfixLocation
impl Eq for BuildfixLocation
impl StructuralPartialEq for BuildfixLocation