pub struct BuildfixMetadata {
pub generated_at: Option<String>,
pub generator: Option<String>,
pub dry_run: Option<bool>,
}Fields
generated_at: Option<String>generator: Option<String>dry_run: Option<bool>Trait Implementations
Sourceimpl Clone for BuildfixMetadata
impl Clone for BuildfixMetadata
Sourcefn clone(&self) -> BuildfixMetadata
fn clone(&self) -> BuildfixMetadata
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BuildfixMetadata
impl Debug for BuildfixMetadata
Sourceimpl<'de> Deserialize<'de> for BuildfixMetadata
impl<'de> Deserialize<'de> for BuildfixMetadata
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BuildfixMetadata
impl JsonSchema for BuildfixMetadata
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for BuildfixMetadata
impl PartialEq for BuildfixMetadata
Sourceimpl Serialize for BuildfixMetadata
impl Serialize for BuildfixMetadata
impl Eq for BuildfixMetadata
impl StructuralPartialEq for BuildfixMetadata