pub struct BuildfixPlanV1 {
pub schema: String,
pub source: BuildfixSourceReport,
pub fixes: Vec<BuildfixFixAction>,
pub metadata: Option<BuildfixMetadata>,
}Fields
schema: Stringsource: BuildfixSourceReportfixes: Vec<BuildfixFixAction>metadata: Option<BuildfixMetadata>Trait Implementations
Sourceimpl Clone for BuildfixPlanV1
impl Clone for BuildfixPlanV1
Sourcefn clone(&self) -> BuildfixPlanV1
fn clone(&self) -> BuildfixPlanV1
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BuildfixPlanV1
impl Debug for BuildfixPlanV1
Sourceimpl<'de> Deserialize<'de> for BuildfixPlanV1
impl<'de> Deserialize<'de> for BuildfixPlanV1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BuildfixPlanV1
impl JsonSchema for BuildfixPlanV1
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for BuildfixPlanV1
impl PartialEq for BuildfixPlanV1
Sourceimpl Serialize for BuildfixPlanV1
impl Serialize for BuildfixPlanV1
impl Eq for BuildfixPlanV1
impl StructuralPartialEq for BuildfixPlanV1