pub struct BuildfixSourceReport {
pub tool: String,
pub report_path: String,
pub report_schema: Option<String>,
}Fields
tool: Stringreport_path: Stringreport_schema: Option<String>Trait Implementations
Sourceimpl Clone for BuildfixSourceReport
impl Clone for BuildfixSourceReport
Sourcefn clone(&self) -> BuildfixSourceReport
fn clone(&self) -> BuildfixSourceReport
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BuildfixSourceReport
impl Debug for BuildfixSourceReport
Sourceimpl<'de> Deserialize<'de> for BuildfixSourceReport
impl<'de> Deserialize<'de> for BuildfixSourceReport
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BuildfixSourceReport
impl JsonSchema for BuildfixSourceReport
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for BuildfixSourceReport
impl PartialEq for BuildfixSourceReport
Sourceimpl Serialize for BuildfixSourceReport
impl Serialize for BuildfixSourceReport
impl Eq for BuildfixSourceReport
impl StructuralPartialEq for BuildfixSourceReport