pub struct ReportEnvelope<TData = DepguardData> {
pub schema: String,
pub tool: ToolMeta,
pub started_at: OffsetDateTime,
pub finished_at: OffsetDateTime,
pub verdict: Verdict,
pub findings: Vec<Finding>,
pub data: TData,
}Expand description
A generic receipt/envelope.
Keeping this generic allows Depguard to embed tool-specific data while still enforcing a stable outer shape.
Fields
schema: StringVersioned schema identifier for the envelope shape.
tool: ToolMetastarted_at: OffsetDateTimefinished_at: OffsetDateTimeverdict: Verdictfindings: Vec<Finding>data: TDataTrait Implementations
Sourceimpl<TData: Clone> Clone for ReportEnvelope<TData>
impl<TData: Clone> Clone for ReportEnvelope<TData>
Sourcefn clone(&self) -> ReportEnvelope<TData>
fn clone(&self) -> ReportEnvelope<TData>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<TData: Debug> Debug for ReportEnvelope<TData>
impl<TData: Debug> Debug for ReportEnvelope<TData>
Sourceimpl<'de, TData> Deserialize<'de> for ReportEnvelope<TData>where
TData: Deserialize<'de>,
impl<'de, TData> Deserialize<'de> for ReportEnvelope<TData>where
TData: Deserialize<'de>,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<TData> JsonSchema for ReportEnvelope<TData>where
TData: JsonSchema,
impl<TData> JsonSchema for ReportEnvelope<TData>where
TData: JsonSchema,
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl<TData: PartialEq> PartialEq for ReportEnvelope<TData>
impl<TData: PartialEq> PartialEq for ReportEnvelope<TData>
Sourceimpl<TData> Serialize for ReportEnvelope<TData>where
TData: Serialize,
impl<TData> Serialize for ReportEnvelope<TData>where
TData: Serialize,
impl<TData> StructuralPartialEq for ReportEnvelope<TData>